If you would like to contribute to the development of OpenStack, you
must follow the steps in this page:

    https://docs.openstack.org/infra/manual/developers.html

Once those steps have been completed, changes to OpenStack should be
submitted for review via the Gerrit tool, following the workflow
documented at:

    https://docs.openstack.org/infra/manual/developers.html#development-workflow

Gerrit is the review system used in the OpenStack projects. We're sorry,
but we won't be able to respond to pull requests submitted through
GitHub.

Bugs should be filed on Launchpad, not Github:

    https://bugs.launchpad.net/python-swiftclient
